capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Run regressions for Appendix Table A.10
Input: 
	zip_for831_FNqtr_forreg (from AEJ_831QTR_PREP3)
*/

use "`data'\zip_for831_FNqtr_forreg.dta", clear;

local pre "12";
local post "8";
scalar define scpre=12;
scalar define scpost=8;


/* ****************************** */
/* **** PREP FOR REGRESSIONS **** */
/* ****************************** */

keep if eqtryear>=-`=scpre' & eqtryear<=`=scpost' ;
tab eqtryear, m;

gen byte pre=(eqtryear<0);
gen byte post=(eqtryear>0);
gen byte qtrzero=(eqtryear==0);

gen trtXpost=treat*post;
gen trtXzero=treat*qtrzero;

/* Create weights */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Convert to log applications variable */
foreach stub in all diadult ssiadult ssikid {;
	summ `stub'_a_ct* `stub'_r_ct*;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var' = 1 if `var'==0;
		replace `var' = log(`var');
	};
	summ `stub'_a_ct* `stub'_r_ct*;
};

/* State X year fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;

/* Group rare ZIPs for suest command */
preserve;
keep if sample_all==1;
collapse (count) eqtryear, by(zip);
rename eqtryear count;
save "`data'\zip_for831_FNqtr_forreg_zipcollapse.dta", replace;
restore;
merge m:1 zip using "`data'\zip_for831_FNqtr_forreg_zipcollapse.dta", keepusing(count);
gen ziped=zip;
replace zip=9 if count<200;
replace ziped=9 if count<1000;


/* ****************************************** */
/* **** TEST APPLICATIONS VS. ALLOWANCES **** */
/* ****************************************** */
xi: reg all_a_ctnum 
	trtXpost trtXzero treat
	i.eqtryear i.stateXyear i.quarter i.zip
	if sample_all==1
	[aweight=weight_a_all]
	;
est store app;

xi: reg all_r_ctnum 
	trtXpost trtXzero treat
	i.eqtryear i.stateXyear i.quarter i.zip 
	if sample_all==1
	[aweight=weight_a_all]
	;
est store allow;

suest app allow, vce(cluster closing);
test [app_mean]trtXpost=[allow_mean]trtXpost;


/* ******************************* */
/* **** TEST ACROSS SUBGROUPS **** */
/* ******************************* */

/* Severity */
foreach stub in sevlow sevmed sevhigh sevvh {;
	xi: reg all_a_ct`stub' 
		trtXpost trtXzero treat
		i.eqtryear i.stateXyear i.quarter i.zip
		if sample_all==1
		[aweight=weight_a_all]
		;
	est store a`stub';
};
suest asevlow asevmed asevhigh asevvh, vce(cluster closing);
test [asevlow_mean]trtXpost=[asevmed_mean]trtXpost;
test [asevlow_mean]trtXpost=[asevhigh_mean]trtXpost;
test [asevlow_mean]trtXpost=[asevvh_mean]trtXpost;
test [asevmed_mean]trtXpost=[asevhigh_mean]trtXpost;
test [asevmed_mean]trtXpost=[asevvh_mean]trtXpost;
test [asevhigh_mean]trtXpost=[asevvh_mean]trtXpost;

foreach stub in sevmed sevhigh sevvh {;
	xi: reg all_r_ct`stub' 
		trtXpost trtXzero treat
		i.eqtryear i.stateXyear i.quarter i.zip
		if sample_all==1
		[aweight=weight_r_all]
		;
	est store r`stub';
};
suest rsevmed rsevhigh rsevvh, vce(cluster closing);
test [rsevmed_mean]trtXpost=[rsevhigh_mean]trtXpost;
test [rsevmed_mean]trtXpost=[rsevvh_mean]trtXpost;
test [rsevhigh_mean]trtXpost=[rsevvh_mean]trtXpost;


foreach gp in a r {;

	/* Disability type */
	foreach stub in bsmental bsmusc bsphys {;
		xi: reg all_`gp'_ct`stub' 
			trtXpost trtXzero treat
			i.eqtryear i.stateXyear i.quarter i.zip
			if sample_all==1
			[aweight=weight_`gp'_all]
			;
		est store `gp'`stub';
	};
	suest `gp'bsmental `gp'bsmusc `gp'bsphys, vce(cluster closing);
	test [`gp'bsmental_mean]trtXpost=[`gp'bsmusc_mean]trtXpost;
	test [`gp'bsmental_mean]trtXpost=[`gp'bsphys_mean]trtXpost;
	test [`gp'bsmusc_mean]trtXpost=[`gp'bsphys_mean]trtXpost;

	/* Education */
	foreach stub in edhsdrop edhsgrad edcollgrad {;
		xi: reg all_`gp'_ct`stub' 
			trtXpost trtXzero treat
			i.eqtryear i.stateXyear i.quarter i.ziped 
			if sample_all==1
			[aweight=weight_`gp'_all]
			;
		est store `gp'`stub';
	};
	suest `gp'edhsdrop `gp'edhsgrad `gp'edcollgrad, vce(cluster closing);
	test [`gp'edhsdrop_mean]trtXpost=[`gp'edhsgrad_mean]trtXpost;
	test [`gp'edhsdrop_mean]trtXpost=[`gp'edcollgrad_mean]trtXpost;
	test [`gp'edhsgrad_mean]trtXpost=[`gp'edcollgrad_mean]trtXpost;

	/* Earnings */
	foreach stub in pearn0 pearn5 pearn15 pearn25 {;
		xi: reg all_`gp'_ct`stub' 
			trtXpost trtXzero treat
			i.eqtryear i.stateXyear i.quarter i.ziped
			if sample_all==1
			[aweight=weight_`gp'_all]
			;
		est store `gp'`stub';
	};
	suest `gp'pearn0 `gp'pearn5 `gp'pearn15 `gp'pearn25, vce(cluster closing);
	test [`gp'pearn0_mean]trtXpost=[`gp'pearn5_mean]trtXpost;
	test [`gp'pearn0_mean]trtXpost=[`gp'pearn15_mean]trtXpost;
	test [`gp'pearn0_mean]trtXpost=[`gp'pearn25_mean]trtXpost;
	test [`gp'pearn5_mean]trtXpost=[`gp'pearn15_mean]trtXpost;
	test [`gp'pearn5_mean]trtXpost=[`gp'pearn25_mean]trtXpost;
	test [`gp'pearn15_mean]trtXpost=[`gp'pearn25_mean]trtXpost;
	
	/* Age */
	foreach stub in age18to34 age35to49 age50plus {;
		xi: reg all_`gp'_ct`stub' 
			trtXpost trtXzero treat
			i.eqtryear i.stateXyear i.quarter i.zip
			if sample_all==1
			[aweight=weight_`gp'_all]
			;
		est store `gp'`stub';
	};
	suest `gp'age18to34 `gp'age35to49 `gp'age50plus, vce(cluster closing);
	test [`gp'age18to34_mean]trtXpost=[`gp'age35to49_mean]trtXpost;
	test [`gp'age18to34_mean]trtXpost=[`gp'age50plus_mean]trtXpost;
	test [`gp'age35to49_mean]trtXpost=[`gp'age50plus_mean]trtXpost;

};
